@@ -127,15 +127,15 @@ char           *cfg_logname = NULL;
 
 /* --- local functions --- */
 static void     lg_print_config();
-static FILE    *lg_parse_config();
-static char    *lg_format_buffer();
-static void     lg_sprint_node();
-static void     lg_sprint_oid();
-static void     lg_sprint_int();
-static void     lg_sprint_ulong();
-static void     lg_sprint_ASNtype();
-static void     lg_sprint_var();
-static void     lg_sprint_string();
+static FILE    *lg_parse_config(char *cfgname);
+static char    *lg_format_buffer(t_trap * p_trap, time_t trap_time);
+static void     lg_sprint_node(char *name, int nodeFmt, char **cPPtr, int *bRemP);
+static void     lg_sprint_oid(char *oidP, int oidFmt, char **cPPtr, int *bRemP);
+static void     lg_sprint_int(int ival, char *iFmt, char **cPPtr, int *bRemP);
+static void     lg_sprint_ulong(unsigned long ival, char *iFmt, char **cPPtr, int *bRemP);
+static void     lg_sprint_ASNtype(u_char asntype, char **cPPtr, int *bRemP);
+static void     lg_sprint_var(t_var *var, char *vFmt, int seqno, char **cPPtr, int *bRemP);
+static void     lg_sprint_string(char *stringP, char **cPPtr, int *bRemP);
 
 static void     free_trap(t_trap * p_trap);
 static void     process_trapdata(FILE * f);
@@ -427,8 +427,7 @@ main(argc, argv)
  *     
  */
 static FILE    *
-lg_parse_config(cfgname)
-     char           *cfgname;
+lg_parse_config(char *cfgname)
 {
   FILE           *cfg;
   FILE           *f_log = NULL;
@@ -789,11 +788,10 @@ lg_format_buffer(t_trap * p_trap, time_t trap_time)
  * output buffer
  */
 static void
-lg_sprint_node(name, nodeFmt, cPPtr, bRemP)
-     char           *name;      /* node name (or ip) */
-     int             nodeFmt;   /* NODEFMT_IP/_FQDN/_NAME */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_node(char           *name,      /* node name (or ip) */
+               int             nodeFmt,   /* NODEFMT_IP/_FQDN/_NAME */
+               char          **cPPtr,     /* address of pointer to current outchar */
+               int            *bRemP     /* address of counter of remaining chars */)
 {
   char            lbuf[80];     /* local buffer for result */
   int             l;
@@ -861,11 +859,10 @@ lg_sprint_node(name, nodeFmt, cPPtr, bRemP)
 /* print an oid according to the specified format into the output buffer 
  */
 static void
-lg_sprint_oid(oidP, oidFmt, cPPtr, bRemP)
-     char           *oidP;      /* the OID */
-     int             oidFmt;    /* OIDFMT_TEXT/_OID */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_oid(char           *oidP,      /* the OID */
+              int             oidFmt,    /* OIDFMT_TEXT/_OID */
+              char          **cPPtr,     /* address of pointer to current outchar */
+              int            *bRemP     /* address of counter of remaining chars */)
 {
   char            lbuf[1024];   /* local buffer */
   int             l;
@@ -902,10 +899,9 @@ lg_sprint_oid(oidP, oidFmt, cPPtr, bRemP)
 /* print a string according to the specified format into the output buffer 
  */
 static void
-lg_sprint_string(stringP, cPPtr, bRemP)
-     char           *stringP;   /* the string */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_string(char           *stringP,   /* the string */
+                 char          **cPPtr,     /* address of pointer to current outchar */
+                 int            *bRemP     /* address of counter of remaining chars */)
 {
   int             l;
 
@@ -930,11 +926,10 @@ lg_sprint_string(stringP, cPPtr, bRemP)
 /* print an integer according to the specified format into the output buffer
  */
 static void
-lg_sprint_int(ival, iFmt, cPPtr, bRemP)
-     int             ival;      /* the integer value */
-     char           *iFmt;      /* the format string */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_int(int             ival,      /* the integer value */
+              char           *iFmt,      /* the format string */
+              char          **cPPtr,     /* address of pointer to current outchar */
+              int            *bRemP     /* address of counter of remaining chars */)
 {
   char            lbuf[20];     /* local buffer */
   int             l;
@@ -963,11 +958,10 @@ lg_sprint_int(ival, iFmt, cPPtr, bRemP)
 /* print an u_long according to the specified format into the output buffer
  */
 static void
-lg_sprint_ulong(uval, uFmt, cPPtr, bRemP)
-     unsigned long   uval;      /* the integer value */
-     char           *uFmt;      /* the format string */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_ulong(unsigned long   uval,      /* the integer value */
+                char           *uFmt,      /* the format string */
+                char          **cPPtr,     /* address of pointer to current outchar */
+                int            *bRemP     /* address of counter of remaining chars */)
 {
   char            lbuf[20];     /* local buffer */
   int             l;
@@ -996,10 +990,9 @@ lg_sprint_ulong(uval, uFmt, cPPtr, bRemP)
 /* print an ASN.1 type ito the output buffer
  */
 static void
-lg_sprint_ASNtype(asntype, cPPtr, bRemP)
-     u_char          asntype;   /* ASN.1 type */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_ASNtype(u_char          asntype,   /* ASN.1 type */
+                  char          **cPPtr,     /* address of pointer to current outchar */
+                  int            *bRemP     /* address of counter of remaining chars */)
 {
   char           *p;
   int             l;
@@ -1072,12 +1065,11 @@ lg_sprint_ASNtype(asntype, cPPtr, bRemP)
  * output buffer
  */
 static void
-lg_sprint_var(var, vFmt, seqno, cPPtr, bRemP)
-     t_var          *var;       /* the snmp variable */
-     char           *vFmt;      /* the output format string */
-     int             seqno;     /* current sequence number */
-     char          **cPPtr;     /* address of pointer to current outchar */
-     int            *bRemP;     /* address of counter of remaining chars */
+lg_sprint_var(t_var          *var,       /* the snmp variable */
+              char           *vFmt,      /* the output format string */
+              int             seqno,     /* current sequence number */
+              char          **cPPtr,     /* address of pointer to current outchar */
+              int            *bRemP     /* address of counter of remaining chars */ )
 {
   char           *vPtr;         /* current varfmt character */
 
